clear
import excel "/Users/apple/Desktop/Honors Thesis/Data Sets/full recoded.xlsx", sheet("Main") firstrow case(lower)

rename q41 continuer //continuer section

*Age and generation
rename q21 age
label var age "Age in years"
zscore age
gen genr = 1
label var genr "Generation"
label define generation 1 "Z" 2 "Milleniaux" 3 "X"
label values genr generation
replace genr = 2 if age > 28 & age < 45
replace genr = 3 if age >= 45

gen genz = 0 
replace genz = 1 if genr == 1
label variable genz "Gen Z dummy"
gen genmil = 0
replace genmil = 1 if genr == 2
label variable genmil "Millenials dummy"
gen genx = 0
replace genx = 1 if genr == 3
label variable genx "Gen X dummy"

*Consumption frequency
rename q141 wine_freq
label var wine_freq "Wine Consumption Frequency"
rename q142 beer_freq
label var beer_freq "Beer Consumption Frequency"
label define consumption_freq 1 "Jamais" 2 "2-5 fois par an" 3 "1 fois par mois" 4 "2-3 fois par mois" 5 "1 fois par semaine" 6 "2-5 fois par semaine" 7 "Tous les jours"
label values wine_freq consumption_freq
label values beer_freq consumption_freq
gen wine_perwk = 0
replace wine_perwk = 0.067 if wine_freq == 2
replace wine_perwk = 0.231 if wine_freq == 3
replace wine_perwk = 0.577 if wine_freq == 4
replace wine_perwk = 1 if wine_freq == 5
replace wine_perwk = 3.5 if wine_freq == 6
replace wine_perwk = 7 if wine_freq == 7
gen beer_perwk = 0
replace beer_perwk = 0.067 if beer_freq == 2
replace beer_perwk = 0.231 if beer_freq == 3
replace beer_perwk = 0.577 if beer_freq == 4
replace beer_perwk = 1 if beer_freq == 5
replace beer_perwk = 3.5 if beer_freq == 6
replace beer_perwk = 7 if beer_freq == 7
summ wine_perwk
summ beer_perwk

gen wine_freq_high = 0
replace wine_freq_high = 1 if wine_perwk >= 1

gen beer_freq_high = 0
replace beer_freq_high = 1 if beer_perwk >= 1

*Lvl of agreement: perception block
rename q152_1 patrim 
label var patrim "Perception (1) : Important comme patrimoine culturel"
rename q152_2 monid
label var monid "Perception (2) : Important pour mon identité française"
rename q152_3 haute 
label var haute "Perception (3) : Produit de haute culture"
rename q152_4 aliment
label var aliment "Perception (4) : Aliment quotidien"
label define Agreement 1 "Pas du tout d'accord" 2 "Pas d'accord" 3 "Plutôt pas d'accord" 4 "Neutre" 5 "Plutôt d'accord" 6 "D'accord" 7 "Tout à fait d'accord"

label values patrim Agreement
label values monid Agreement
label values haute Agreement
label values aliment Agreement

*Lvl of agreement: consumption block
rename q154_1 facile 
label var facile "Consommation(1) : Il est facile de choisir le type de vin à acheter/boire."
rename q154_2 soliciter
label var soliciter "Consommation(2): Je suis souvent sollicité(e) par ma famille ou mes amis pour les aider à choisir du vin."
rename q154_3 aimervin
label var aimervin "Consommation(3): J'aime boire le vin en général."
rename q154_4 aimerbiere
label var aimerbiere "Consommation(4): J'aime boire la bière en général."

label values facile Agreement
label values soliciter Agreement
label values aimervin Agreement
label values aimerbiere Agreement


*Lvl of agreement: attitude block
rename q156_1 appartgenr 
label var appartgenr "Attitude(1) : J'ai le sentiment que j'appartiens à ma génération."
rename q156_2 risquesante
label var risquesante "Attitude(2) : Les boissons alcoolisées posent un  risque à la santé publique."
rename q156_3 envrperil
zscore envrperil
label var envrperil "Attitude(3) : L'environnement est en péril."
rename q156_4 anglmenace
label var anglmenace "Attitude(4) : L'anglicisme est une menace pour la langue française."

label values appartgenr Agreement
label values risquesante Agreement
label values envrperil Agreement
label values anglmenace Agreement


*Proxies
rename q161 habiterhors
label var habiterhors "Proxy : Combien de temps avez-vous habité en dehors de la France jusqu'à présent ?"
label define habiterhors 1 "Moins de 6 mois" 2 "6 mois - 1 an" 3 "1-3 ans" 4 "3-5 ans" 5 "5 ans et +"
label values habiterhors habiterhors
rename q162 rssociaux
label var rssociaux "Proxy : A quelle fréquence utilisez-vous les réseaux sociaux ?"
label define rssociaux 1 "Jamais" 2 "Moins d'une heure par jour" 3 "1-2 heures par jour" 4 "2-3 heures par jour" 5 "3+ heures par jour"
label values rssociaux rssociaux
rename q163 films
label var films "Proxy : De tous les films que vous avez regardés en 2024, quel pourcentage était français ?"
label values films films
gen films_high = 0
replace films_high = 1 if films >= 3
rename q164 resplibre
label var resplibre "Response libre : décrire le consommateur typique du vin"

*Demographic information
rename q181 sexe
label var sexe "0 = M, 1 = F, -2 = Autre"
gen female = 0 
replace female = 1 if sexe == 1 
replace female =. if sexe == -2 
label variable female "0 = M, 1= F"
rename q182 paysnaiss
destring paysnaiss, replace
label var paysnaiss "Pays de naissance"
replace paysnaiss =. if paysnaiss == -99|paysnaiss == 0
label define paysnaiss 1 "France métropolitaine" 2 "DOM/TOMs" 3 "Autre pays/région"
gen paysnaiss_dum = 0
replace paysnaiss_dum = 1 if paysnaiss == 1
label variable paysnaiss_dum "Born in France métropolitaine"
rename paysnaiss_dum france_dum
label values paysnaiss paysnaiss
rename q183 paysorg_pr
destring paysorg_pr, replace
label var paysorg_pr "Pays d'origine de parents"
label define paysorg_pr 1 "France métropolitaine (2 parents)" 2 "France métropolitaine (1 parent) + autre pays/région (1 parent)" 3 "Autre pays/région (2 parents)" 4 "France métropolitaine (j'ai seulement 1 parent)" 5 "Autre pays/région (j'ai seulement 1 parent)" -99 "Je ne sais pas"
label values paysorg_pr paysorg_pr

gen france_pr_dum = 0
replace france_pr_dum = 1 if paysorg_pr == 1|paysorg_pr == 2|paysorg_pr == 4 //at least 1 parent born in France metrop
label variable france_pr_dum "At least 1 parent born in France métropolitaine"

rename q184 adultes
label var adultes "Combien d'adultes dans foyer"
rename q185 revenu
label var revenu "Le revenu net de foyer chaque mois"
destring revenu, replace
label define revenu 1 "Moins de 1000 euros" 2 "Entre 1001 et 2000 euros" 3 "Entre 2001 et 3000 euros" 4 "Entre 3001 et 4000 euros" 5 "Entre 4001 et 5000 euros" 7 "Entre 7001 et 10000 euros" 6 "Entre 5001 et 7000 euros" 8 "Plus de 10000 euros" -99 "Je ne sais pas"
replace revenu =. if revenu == -99
label values revenu revenu
tab revenu
gen revenu_mp =. //midpoint in euros
replace revenu_mp = 500 if revenu == 1
replace revenu_mp = 1500 if revenu == 2
replace revenu_mp = 2500 if revenu == 3
replace revenu_mp = 3500 if revenu == 4
replace revenu_mp = 4500 if revenu == 5
replace revenu_mp = 6000 if revenu == 6
replace revenu_mp = 8500 if revenu == 7
replace revenu_mp = 12500 if revenu == 8

summ revenu_mp


*Treatment, Framing, DCE Block

gen treat = 0
replace treat = 1 if continuer == "" //continuer = did not see video
label var treat "Identity Video Treatment"

gen framing_plaisir = 0
replace framing_plaisir = 1 if f1b1 != -99 | f1b5 != -99 | f1b9 != -99 //any of the framing 1 questions has value
gen framing_famille = 0
replace framing_famille = 1 if f2b1 != -99 | f2b5 != -99 | f2b9 != -99 //any of the framing 2 questions has value
gen framing_amis = 0
replace framing_amis = 1 if f3b1 != -99 | f3b5 != -99 | f3b9 != -99 //any of the framing 3 questions has value

gen framing = 1
replace framing = 2 if framing_famille == 1
replace framing = 3 if framing_amis == 1
label define framing 1 "plaisir" 2 "famille" 3 "amis"
label values framing framing
label variable framing "1 = plaisir, 2 = famille, 3 = amis"


* Replace -99 with missing (.) for all f()b() variables
local groups 1 2 3
local b_vals 1 2 3 4 5 6 7 8 9 10 11 12

foreach g of local groups {
    foreach b of local b_vals {
        local varname f`g'b`b'
        quietly replace `varname' = . if `varname' == -99
    }
}

* Verify the changes
list f1b1-f1b12 f2b1-f2b12 f3b1-f3b12 if framing_plaisir == 1 | framing_famille == 1 | framing_amis == 1

gen choice1 = .
gen choice2 = .
gen choice3 = .
gen choice4 = .

replace choice1 = f1b1 if f1b1 !=. & framing_plaisir == 1
replace choice2 = f1b2 if f1b2 !=. & framing_plaisir == 1
replace choice3 = f1b3 if f1b3 !=. & framing_plaisir == 1
replace choice4 = f1b4 if f1b4 !=. & framing_plaisir == 1
replace choice1 = f1b5 if f1b5 !=. & framing_plaisir == 1
replace choice2 = f1b6 if f1b6 !=. & framing_plaisir == 1
replace choice3 = f1b7 if f1b7 !=. & framing_plaisir == 1
replace choice4 = f1b8 if f1b8 !=. & framing_plaisir == 1
replace choice1 = f1b9 if f1b9 !=. & framing_plaisir == 1
replace choice2 = f1b10 if f1b10 !=. & framing_plaisir == 1
replace choice3 = f1b11 if f1b11 !=. & framing_plaisir == 1
replace choice4 = f1b12 if f1b12 !=. & framing_plaisir == 1

replace choice1 = f2b1 if f2b1 !=. & framing_famille == 1
replace choice2 = f2b2 if f2b2 !=. & framing_famille == 1
replace choice3 = f2b3 if f2b3 !=. & framing_famille == 1
replace choice4 = f2b4 if f2b4 !=. & framing_famille == 1
replace choice1 = f2b5 if f2b5 !=. & framing_famille == 1
replace choice2 = f2b6 if f2b6 !=. & framing_famille == 1
replace choice3 = f2b7 if f2b7 !=. & framing_famille == 1
replace choice4 = f2b8 if f2b8 !=. & framing_famille == 1
replace choice1 = f2b9 if f2b9 !=. & framing_famille == 1
replace choice2 = f2b10 if f2b10 !=. & framing_famille == 1
replace choice3 = f2b11 if f2b11 !=. & framing_famille == 1
replace choice4 = f2b12 if f2b12 !=. & framing_famille == 1

replace choice1 = f3b1 if f3b1 !=. & framing_amis == 1
replace choice2 = f3b2 if f3b2 !=. & framing_amis == 1
replace choice3 = f3b3 if f3b3 !=. & framing_amis == 1
replace choice4 = f3b4 if f3b4 !=. & framing_amis == 1
replace choice1 = f3b5 if f3b5 !=. & framing_amis == 1
replace choice2 = f3b6 if f3b6 !=. & framing_amis == 1
replace choice3 = f3b7 if f3b7 !=. & framing_amis == 1
replace choice4 = f3b8 if f3b8 !=. & framing_amis == 1
replace choice1 = f3b9 if f3b9 !=. & framing_amis == 1
replace choice2 = f3b10 if f3b10 !=. & framing_amis == 1
replace choice3 = f3b11 if f3b11 !=. & framing_amis == 1
replace choice4 = f3b12 if f3b12 !=. & framing_amis == 1

*replace choice variables with remainder of division by 2. if choice1 == 1, then the choice is a conventional French wine, and 0 otherwise. -2 means choice of ni l'une ni l'autre
replace choice1 = mod(choice1, 2) if choice1 != -2
replace choice2 = mod(choice2, 2) if choice2 != -2
replace choice3 = mod(choice3, 2) if choice3 != -2
replace choice4 = mod(choice4, 2) if choice4 != -2

replace choice3 = 1 - choice3 if choice3 != -2 //swap 1 and 0 for consistency

label define choice1 0 "bière ambrée" 1 "vin rouge français" -2 "ni l'une ni l'autre"

label define choice2 0 "bière blonde" 1 "vin blanc français" -2 "ni l'une ni l'autre"

label define choice3 0 "vin rouge français" 1 "vin rouge américain" -2 "ni l'une ni l'autre"

label define choice4 0 "vin rouge bio (français)" 1 "vin rouge conventionnel (français)" -2 "ni l'une ni l'autre"

label values choice1 choice1
label values choice2 choice2
label values choice3 choice3
label values choice4 choice4

label variable choice1 "vin rouge vs bière ambrée"
label variable choice2 "vin blanc vs bière blonde"
label variable choice3 "vin fr vs vin USA"
label variable choice4 "vin conv. vs vin bio"

gen choice1_dum = 0
replace choice1_dum = 1 if choice1 == 1
replace choice1_dum =. if choice1 == -2

gen choice2_dum = 0
replace choice2_dum = 1 if choice2 == 1
replace choice2_dum =. if choice2 == -2

gen choice12_dum = (choice1_dum + choice2_dum)/2 //choice1 and 2 taken together

gen choice3_dum = 0
replace choice3_dum = 1 if choice3 == 1
replace choice3_dum =. if choice3 == -2

gen choice4_dum = 0
replace choice4_dum = 1 if choice4 == 1
replace choice4_dum =. if choice4 == -2

gen id_diff = patrim - monid

gen nonbuveur_dum = 0 
replace nonbuveur_dum = 1 if beer_freq == 1 & wine_freq == 1
label variable nonbuveur_dum "Non drinker dummy"

zscore monid //standardized monid

gen appartgenr_dum = 0
replace appartgenr_dum = 1 if appartgenr > 3
replace appartgenr_dum =. if appartgenr == 3

gen habiterhors_m = 3
replace habiterhors_m = 9 if habiterhors == 2
replace habiterhors_m = 24 if habiterhors == 3
replace habiterhors_m = 46 if habiterhors == 4
replace habiterhors_m = 90 if habiterhors == 5

gen habiterhors_pc = habiterhors_m/12/age
tab habiterhors_pc

gen habiterhors_sq = habiterhors*habiterhors


**identity strength index
zscore films
zscore rssociaux
 //reverse effect for consistent interpretation. Now higher rssoiaux = higher identity
zscore anglmenace
zscore habiterhors_m
zscore habiterhors_pc
zscore habiterhors
gen idindex = z_films + z_anglmenace + z_habiterhors - z_rssociaux

*wine knowledge index
gen wineknow = (facile+soliciter)/2
zscore wineknow

*young vs old, neglecting millenials
gen young = 0
replace young = 1 if genx == 1
replace young =. if genmil == 1
